@@ -3,6 +3,7 @@ from math import sqrt
 import os
 from fontTools.pens.basePen import BasePen
 from fontTools.ttLib.tables.otTables import CompositeMode, ExtendMode
+from CoreFoundation import CFDataCreateMutable
 import Quartz as CG
 from .base import Canvas, Surface
 from .sweepGradient import buildSweepGradientPatches
@@ -217,27 +218,53 @@ def _unpackColorLine(colorLine):
 class CoreGraphicsPixelSurface(Surface):
     fileExtension = ".png"
 
-    def __init__(self, boundingBox):
+    def __init__(self):
+        self.context = None
+
+    @contextmanager
+    def canvas(self, boundingBox):
         x, y, xMax, yMax = boundingBox
         width = xMax - x
         height = yMax - y
+        self._setupCGContext(x, y, width, height)
+        yield CoreGraphicsCanvas(self.context)
+
+    def _setupCGContext(self, x, y, width, height):
         rgbColorSpace = CG.CGColorSpaceCreateDeviceRGB()
-        # rgbColorSpace = CG.CGColorSpaceCreateWithName(CG.kCGColorSpaceSRGB)
         self.context = CG.CGBitmapContextCreate(
             None, width, height, 8, 0, rgbColorSpace, CG.kCGImageAlphaPremultipliedFirst
         )
         CG.CGContextTranslateCTM(self.context, -x, -y)
-        self._canvas = CoreGraphicsCanvas(self.context)
-
-    @property
-    def canvas(self):
-        return self._canvas
 
     def saveImage(self, path):
         image = CG.CGBitmapContextCreateImage(self.context)
         saveImageAsPNG(image, path)
 
 
+class CoreGraphicsPDFSurface(CoreGraphicsPixelSurface):
+    fileExtension = ".pdf"
+
+    @contextmanager
+    def canvas(self, boundingBox):
+        with super().canvas(boundingBox) as canvas:
+            CG.CGContextBeginPage(self.context, self._mediaBox)
+            yield canvas
+            CG.CGContextEndPage(self.context)
+
+    def _setupCGContext(self, x, y, width, height):
+        if self.context is None:
+            self._mediaBox = ((x, y), (width, height))
+            self._data = CFDataCreateMutable(None, 0)
+            consumer = CG.CGDataConsumerCreateWithCFData(self._data)
+            self.context = CG.CGPDFContextCreate(consumer, self._mediaBox, None)
+        return self.context
+
+    def saveImage(self, path):
+        CG.CGPDFContextClose(self.context)
+        with open(path, "wb") as f:
+            f.write(self._data)
+
+
 def saveImageAsPNG(image, path):
     path = os.path.abspath(path).encode("utf-8")
     url = CG.CFURLCreateFromFileSystemRepresentation(None, path, len(path), False)
