@@ -180,23 +180,67 @@ def _unpackColorLine(colorLine):
     return colors, stops
 
 
-class SkiaPixelSurface(Surface):
-    fileExtension = ".png"
-
-    def __init__(self, boundingBox):
+class _SkiaBaseSurface(Surface):
+    @contextmanager
+    def canvas(self, boundingBox):
         x, y, xMax, yMax = boundingBox
         width = xMax - x
         height = yMax - y
-        self.surface = skia.Surface(width, height)
-        self.skCanvas = self.surface.getCanvas()
-        self.skCanvas.translate(-x, height + y)
-        self.skCanvas.scale(1, -1)
-        self._canvas = SkiaCanvas(self.skCanvas)
+        skCanvas, surfaceData = self._setupSkCanvas(x, y, width, height)
+        skCanvas.translate(-x, height + y)
+        skCanvas.scale(1, -1)
+        yield SkiaCanvas(skCanvas)
+        self._finalizeCanvas(surfaceData)
 
-    @property
-    def canvas(self):
-        return self._canvas
+
+class SkiaPixelSurface(_SkiaBaseSurface):
+    fileExtension = ".png"
+
+    def __init__(self):
+        self._image = None
+
+    def _setupSkCanvas(self, x, y, width, height):
+        surface = skia.Surface(width, height)
+        return surface.getCanvas(), surface
+
+    def _finalizeCanvas(self, surface):
+        self._image = surface.makeImageSnapshot()
 
     def saveImage(self, path, format=skia.kPNG):
-        image = self.surface.makeImageSnapshot()
-        image.save(os.fspath(path), format)
+        self._image.save(os.fspath(path), format)
+
+
+class SkiaPDFSurface(_SkiaBaseSurface):
+    fileExtension = ".pdf"
+
+    def __init__(self):
+        self._pictures = []
+
+    def _setupSkCanvas(self, x, y, width, height):
+        recorder = skia.PictureRecorder()
+        return recorder.beginRecording(width, height), recorder
+
+    def _finalizeCanvas(self, recorder):
+        self._pictures.append(recorder.finishRecordingAsPicture())
+
+    def saveImage(self, path):
+        stream = skia.FILEWStream(os.fspath(path))
+        with skia.PDF.MakeDocument(stream) as document:
+            for picture in self._pictures:
+                x, y, width, height = picture.cullRect()
+                assert x == 0 and y == 0
+                with document.page(width, height) as canvas:
+                    canvas.drawPicture(picture)
+        stream.flush()
+
+
+class SkiaSVGSurface(SkiaPDFSurface):
+    fileExtension = ".svg"
+
+    def saveImage(self, path):
+        stream = skia.FILEWStream(os.fspath(path))
+        picture = self._pictures[-1]
+        canvas = skia.SVGCanvas.Make(picture.cullRect(), stream)
+        canvas.drawPicture(picture)
+        del canvas  # hand holding skia-python with GC: it needs to go before stream
+        stream.flush()
